<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package    format_iena
 * @category   format
 * @copyright  2018 Softia/Université lorraine
 * @author     Thomas Fradet
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

global $COURSE, $DB, $USER, $CFG;

require_once($CFG->libdir . '/completionlib.php');
$completion = new completion_info($course);
$context = context_course::instance($COURSE->id);

/* Groupe du GET provenant du sélecteur de la page du cours, ou premier groupe de l'utilisateur, ou groupe 0 (tous les groupes). */
$active_group_id = $_GET['groupid'];
// @TODO à supprimer si pas utilisé dans le JS (mettre dans la clause IF pour éviter un appel inutile si le GET existe)
$current_user_groups_ids = groups_get_user_groups($COURSE->id, $USER->id)[0];
/* Si pas de groupe dans le get ou groupe 0 (tous) mais pas le droit => premier groupe existant du user ou groupe 0 (tous) */
if ($active_group_id == NULL || ($active_group_id == 0 && !has_capability('course/iena:suivi_edit', $context, $USER->id)) ) {
	if ( count($current_user_groups_ids) == 0 ) {
		$active_group_id = 0;
	} else {
		$active_group_id = $current_user_groups_ids[0];
	}
}

/* Groupes du cours avec id, nom et liste des id utilisateur de tous les membres (3 clefs d'un tableau de groupes : id, name, member) */
if ( $active_group_id == 0 ) {
	$groups = groups_get_all_groups($COURSE->id, 0, 0, 'g.*', true);
} else {
	$groups = groups_get_all_groups($COURSE->id, 0, 0, 'g.*', false);
}

$current_user_groups = [];
$active_group_name = "";
foreach ($groups as $group) {
	/* Récupération du nom du group actif au passage */
	if ( $group->id == $active_group_id ) {
		$active_group_name = $group->name;
	}
	foreach ($current_user_groups_ids as $ugi) {
		if ( $group->id == $ugi ) {
			$current_user_groups[] = $group;
		}
	}
}

/* Liste de tous les utilisateurs avec : 
- informations personnelles (tous les utilisateurs du cours)
- liste des activités avec état d'achèvement (si achevées, sinon vide) */
$progress = $completion->get_progress_all(
	'',
	array(),
	$active_group_id,
	'u.lastname ASC, u.firstname ASC',
	'',
	'',
	$context
);

/* Ajoute les groupes de l'utilisateur pour l'afficher dans l'export */
/* Si le user a le droit d'afficher pour tous les groupes ou qu'il n'y en a pas, on récupère le groupe de l'utilisateur pour qu'il puisse être téléchargé dans le tableau blobal intergroupe. */
if ( $active_group_id == 0 ) {
	foreach ($progress as $prog) {
		$prog->groups = "";
		foreach ($groups as $group) {
			if ( in_array($prog->id, $group->members) ) {
				$prog->groups .= $group->name . " ";
			}
		}
	}
}

/* Liste de toutes les activités du cours (sauf en attente de suppression). La liste est épurée et constitue un tableau d'objet. */
$activities = $completion->get_activities();
$modules = [];
foreach ($activities as $activity) {
	$module = new StdClass();
	$module->id = $activity->id;
	$module->name = $activity->name;
	$displayname = format_string($activity->name, true, array('context' => $activity->context));
	$module->displayname = strlen($displayname) > 20 ? mb_substr($displayname, 0, 19, 'UTF-8').'…' : $displayname;
	$module->section = $activity->section;
	$modules[] = $module;
}

// Liste des sections du cours
$modinfo = get_fast_modinfo($COURSE->id);
$sections_info_all = $modinfo->get_section_info_all();
$sections = [];
foreach ($sections_info_all as $key => $section_info) {
	$section = new StdClass();
	$section->id = $section_info->id;
	$section->name = $section_info->name === NULL ? 'Section ' . $key : $section_info->name;
	$sections[$key] = $section;
}

// Section du get acquise depuis le clic sur l'indicateur dans la page du cours, section depuis laquelle on a cliqué sur le bouton pour voir le suivi. 
$active_section_id = $_GET['sectionid'];
if ($active_section_id == NULL) {
	// no param given for section : first section (index 1, not generalities section 0)
	$active_section_id = 0;
}
// $active_section_name = "Toutes les sections";
// foreach ($sections as $section) {
// 	if ($section->id == $active_section_id) {
// 		$active_section_name = $section->name;
// 	}
// }

// Filtre actif si il existe (si la page est rechargée pour un filtre de groupe p.ex.)
if (isset($_GET['filter'])) {
	$filter = $_GET['filter'];
} else {
	$filter = 'all';
}

// echo "<pre>";
// var_dump($progress);
// var_dump($sections);
// var_dump($modules);
// print_r($groups);
// var_dump($results);
// var_dump($current_user_groups_ids);
// var_dump($current_user_groups);
// echo "</pre>";

?>

<style>
	/* Permet la rotation des entêtes du tableau */
	th.th-rotate {
		/* Something you can count on */
		height: 140px;
		white-space: nowrap;
	}

	th.th-rotate > div {
		transform: 
		/* Magic Numbers */
		translate(17px, 49px)
		/* 45 is really 360 - 45 */
		rotate(315deg);
		width: 30px;
	}
	th.th-rotate > div > span {
		border-bottom: 1px solid #ccc;
		padding: 5px 10px;
	}
	/* Change la couleur une ligne sur deux dans le tableau */
	#table-body tr:nth-child(even) { background: #fafafa; }
	#table-body tr:nth-child(odd) { background: #eee; }
	/* Colorie la cellule en fonction de l'achèvement */
	.state-0 { background-color: rgba(0, 143, 132, 0.23); }
	.state-1 { background-color: #009085; }
	.state-2 { background-color: #009085; }
	.state-3 { background-color: rgba(214, 141, 1, 0.4); }


	#first-column-head {
		vertical-align: bottom;
		padding-bottom: 0.5rem;
	}

	.pointer-help {
		cursor: help;
	}

	.stud_perc {
		min-width: 45px;
		display: inline-block;
	}

	#table-body td { border-right: 1px solid #eee; }

	/* Scroll de la table */
	#table-body {
		display: block; 
		overflow-y:scroll; 
		margin-right: 10rem;
		height: 300px;
		height: 50vh; 
	}

	#suivi {
		margin-bottom: 1rem;
	}

	#suivi thead {
		display: block; overflow-x:scroll;
	}

	#suivi thead tr th:nth-child(1) {
		width:20em;
		min-width:20em;
	}
	#suivi thead tr th {
		min-width:32px;
	}
	#suivi tbody tr th {
		width:20em;
		min-width:20em;
		word-break: break-word;
	}
	#suivi tbody tr td {
		min-width:32px;
	}

	#suivi input[type="checkbox"] {
		margin: 5px;
		font-size: 1rem;
	}

	.mb1 { margin-bottom: 1rem; }
	.mt1 { margin-top: 1rem; }

</style>

<div>

	<h2 class="mb1" style="display: inline-block;">Suivi des étudiants</h2>

	<div style="float: right; line-height: 3rem;">
		<?php
		if (has_capability('course/iena:suivi_edit', $context = context_course::instance($COURSE->id), $USER->id)) {
			echo '<a target="_blank" href="' . $CFG->wwwroot . "/course/bulkcompletion.php?id=" . $COURSE->id . '">Paramétrer le suivi</a> || ';
		} 
		?>
		<a target="_blank" href="<?php echo $CFG->wwwroot."/report/progress/index.php?course=".$COURSE->id ?>">Vue classique</a>
	</div>

</div>

<form style="clear: right;" class="form-inline" action="<?php echo $CFG->wwwroot."/course/format/iena/suivi_unit.php" ?>" method="GET">
	<input name="courseid" type="number" hidden="hidden" style="display: none;" value="<?php echo $COURSE->id ?>">

	<label class="sr-only" for="section-select">Section</label>
	<div class="input-group">
		<div class="input-group-prepend">
			<div class="input-group-text">Section</div>
		</div>
		<select class="custom-select mr-sm-2" id="section-select" name="sectionid">
			<option value="0">Toutes</option>
			<?php 
			foreach ($sections as $section) {
				if ($section->id == $active_section_id) {
					echo "<option selected='selected' value='$section->id'>$section->name</option>";
				} else {
					echo "<option value='$section->id'>$section->name</option>";
				}
			} ?>
		</select>
	</div>

	<label class="sr-only" for="group-select">Groupes</label>
	<div class="input-group">
		<div class="input-group-prepend">
			<div class="input-group-text">Groupes</div>
		</div>
		<select class="custom-select mr-sm-2" id="group-select" name="groupid">
			<option value="0">Tous</option>
			<?php 
			if ( count(current_user_groups) > 0 ) {
				echo '<optgroup label="Mes groupes">';
				foreach ($current_user_groups as $group) {
					if ( $group->id == $active_group_id ) {
						echo "<option selected='selected' value='$group->id'>$group->name</option>";
					} else {
						echo "<option value='$group->id'>$group->name</option>";
					}
				}
				echo '</optgroup>';
			}
			echo '<optgroup label="Autres groupes">';
			foreach ($groups as $group) {
				if ( ! in_array($group->id, $current_user_groups_ids) ) {
					if ($group->id == $active_group_id) {
						echo "<option selected='selected' value='$group->id'>$group->name</option>";
					} else {
						echo "<option value='$group->id'>$group->name</option>";
					}
				}
			} 
			echo '</optgroup>';
			?>
		</select>
	</div>

	<label class="sr-only" for="filter-select">Filtre %</label>
	<div class="input-group">
		<div class="input-group-prepend">
			<div class="input-group-text">Filtre</div>
		</div>
		<select class="custom-select mr-sm-2" id="filter-select" name="filter">
			<?php 
			$filters = [
				"all" => "Tous",
				"=100" => "100%",
				"=0" => "0%",
				"<100" => "&lt;100%",
				"<50" => "&lt;50%",
				"<25" => "&lt;25%",
				">50" => "&gt;=50%",
				">25" => "&gt;=25%",
				">0" => "&gt;0%",
			];
			var_dump($filter);
			foreach ($filters as $value => $name) {
				if ( $value == $filter ) {
					echo "<option selected='selected' value='$value'>$name</option>";
				} else {
					echo "<option value='$value'>$name</option>";
				}
			}
			?>
		</select>
	</div>



</form>

<!-- <div style="text-align: right;">
	<?php
	if (has_capability('course/iena:suivi_edit', $context = context_course::instance($COURSE->id), $USER->id)) {
		echo '<a target="_blank" href="' . $CFG->wwwroot . "/course/bulkcompletion.php?id=" . $COURSE->id . '">Paramétrer le suivi</a> || ';
	} 
	?>
	<a target="_blank" href="<?php echo $CFG->wwwroot."/report/progress/index.php?course=".$COURSE->id ?>">Vue classique</a>
</div> -->

<div class="mt1">
	<a href="#" class="select_all_studs">Sélectionner tout</a> || <a href="#" class="send_msg_sel">Message aux étudiants sélectionnés</a>
</div>

<div id="no_result" class="alert alert-warning" style="display: none;">Aucun étudiants trouvé. Vérifiez la section, le groupe et le filtre choisi.</div>

<div id="no_result_activity" class="alert alert-warning" style="display: none;">Aucune activité se semble suivie pour cette section. </div>

<table id="suivi">
	<thead>
		<tr id="modules" style="">
			<th id="first-column-head">Étudiants</th>
		</tr>
	</thead>
	<tbody id="table-body">
	</tbody>
</table>

<a href="#" class="select_all_studs">Sélectionner tout</a> || <a href="#" class="send_msg_sel">Message aux étudiants sélectionnés</a>

<form id="send_msg_form" hidden="hidden" style="display: none;" action="<?php echo $CFG->wwwroot."/course/format/iena/suivi_unit.php?courseid=".$COURSE->id ?>" method="POST">
	<input id="send_msg_input" type="text" name="api_url" />
</form>

<div class="table-dl">
	<a href="#">Télécharger ce tableau</a>
	<p>Télécharge le tableau pour la section et le groupe sélectionné en haut de page. Les autres filtres ne sont pas pris en compte pour cet export. Sélectionnez "Tout" en haut de page pour chaque filtre si vous souhaitez le tableau complet. Dans le tableau téléchargé : 0 = non achevé ; 1 = achevé ; 0,5 = essayé mais échoué ; 2 = réussi. </p>
</div>

<script type="text/javascript">
//
var data = {
	all_selected: false,
	active_section_id: <?php echo $active_section_id; ?>,
	progress: <?php echo json_encode( array_values($progress) ); ?>,
	modules: <?php echo json_encode( $modules ); ?>,
	groups: <?php echo json_encode( $groups ); ?>,
	active_group_name: "<?php echo $active_group_name; ?>",
	sections: <?php echo json_encode( $sections ); ?>,
};
//
(function () {

	set_table_head();
	set_table_body();
	set_reactivity();

	function count_lines () {
		var rows = document.querySelectorAll("#table-body > tr"); 
		var counter = 0;
		for (var i = 0; i < rows.length; i++) {
			if (rows[i].style.display != "none") {
				counter++;
			}
		}
		var no_rows = false;
		if (counter == 0) {
			no_rows = true;
		}

		var cols = document.querySelectorAll("#suivi > thead > tr > th.th-rotate");
		var counter = 0;
		for (var i = 0; i < cols.length; i++) {
			if (cols[i].style.display != "none") {
				counter++;
			}
		}
		var no_cols = false;
		if (counter == 0) {
			no_cols = true;
		}

		if (no_cols) {
			document.getElementById('no_result_activity').style.display = "";
			document.getElementById('no_result').style.display = "none";
			document.getElementById('suivi').style.display = "none";
		} else if (no_rows) {
			document.getElementById('no_result_activity').style.display = "none";
			document.getElementById('no_result').style.display = "";
			document.getElementById('suivi').style.display = "none";
		} else {
			document.getElementById('no_result_activity').style.display = "none";
			document.getElementById('no_result').style.display = "none";
			document.getElementById('suivi').style.display = "";
		}

	}

	function set_table_head() {
		/* Insert la liste d'activité en entête */
		var table_heads = document.getElementById('modules');
		for (var i = 0; i < data.modules.length; i++) {
			var th = document.createElement('th');
			var div = document.createElement('div');
			var span = document.createElement('span');
			var display_name = document.createTextNode(data.modules[i].displayname);
			th.setAttribute('class', 'th-rotate');
			th.id = data.modules[i].id;
			th.dataset.fullname = data.modules[i].name;
			th.dataset.section = data.modules[i].section;
			span.append(display_name);
			div.append(span);
			th.append(div);
			table_heads.append(th);
		}
	}

	function set_table_body() {

		/* Insert une ligne d'étudiant dans le tbody */
		var table_body = document.getElementById('table-body');
		for (var i = 0; i < data.progress.length; i++) {
			var student = data.progress[i]
			/* Nom de l'étudiant */
			var tr = document.createElement('tr');
			tr.dataset.userid = student.id;
			var th = document.createElement('th');
			// th.dataset.stud_id = student.id;
			var student_full_name = document.createTextNode(student.firstname + " " + student.lastname)

			/* TODO: boutons lien vers rapports de l'étudiant */

			/* Etat d'achèvement de l'étudiant et pourcentage de l'étudiant */
			var tds = [];
			for (var j = 0; j < data.modules.length; j++) {
				var td = document.createElement('td');
				td.title = data.modules[j].name;
				td.dataset.section = data.modules[j].section;
				td.setAttribute('class', 'pointer-help state-0');
				if ( student.progress[data.modules[j].id] !== undefined ) {
					var stud_mod = student.progress[data.modules[j].id];
					td.setAttribute('class', 'pointer-help state-' + stud_mod.completionstate);
				}
				tds.push(td);
			}

			/* Check pour envoyer des message à plusieurs après avoir filtré */
			var check = document.createElement('input');
			check.type = "checkbox";
			th.append(check);

			/* Span où sera placé le pourcentage qui doit être raffraichit dynamiquement par la suite */
			var span = document.createElement('span');
			span.setAttribute('class', 'stud_perc');
			th.append(span);

			/* Icons liens vers rapports et message étudiants */
			/* Lien vers le rapport de cours résumé */
			var href = "<?php echo $CFG->wwwroot . "/report/outline/user.php?id=" ?>" + student.id + "<?php echo "&course=" . $COURSE->id . "&mode=outline" ?>";
			var icon = document.createElement('i');
			icon.setAttribute('class', 'icon fa fa-graduation-cap fa-fw');
			var link = document.createElement('a');
			link.href = href;
			link.setAttribute('target', '_blank');
			link.append(icon);
			th.append(link);
			/* Lien vers un message personnel */
			href = "<?php echo $CFG->wwwroot . "/message/index.php?id=" ?>" + student.id;
			icon = document.createElement('i');
			icon.setAttribute('class', 'icon fa fa-envelope fa-fw');
			link = document.createElement('a');
			link.href = href;
			link.setAttribute('target', '_blank');
			link.append(icon);
			th.append(link);

			th.append(student_full_name);
			tr.append(th);
			for (var k = 0; k < tds.length; k++) {
				tr.append(tds[k]);
			}
			table_body.append(tr);

		}

	}

	function set_reactivity() {

		/* Réactivité sur le sélecteur de section */
		var section_sel = document.getElementById('section-select');
		section_filter(section_sel.value);
		section_sel.onchange = function (e) {
			data.active_section_id = parseInt(e.target.value);
			section_filter(e.target.value);
			display_percentage();
			filter_students(document.getElementById('filter-select').value);
		}

		display_percentage();

		/* Réactivité sur le sélecteur de groupe */
		var group_sel = document.getElementById('group-select');
		group_sel.onchange = function () {
			this.form.submit();
		}

		/* Réactivité sur le filtre de pourcentage d'achèvement */
		var filter_sel = document.getElementById('filter-select');
		filter_students("<?php echo $filter; ?>");
		filter_sel.onchange = function (e) {
			filter_students(e.target.value);
		}

		var select_all_studs_boxes = document.querySelectorAll('.select_all_studs');
		for (var i = 0; i < select_all_studs_boxes.length; i++) {
			select_all_studs_boxes[i].onclick = function (e) {
				select_all_studs(e);
			}
		}

		/* Change le label sélectionner tout par désélectionner tout quand une case est cochée */
		var checks = document.querySelectorAll("#table-body input[type='checkbox']");
		for (var j = 0; j < checks.length; j++) {
			checks[j].onclick = function (e) {
				if ( e.target.checked ) {
					var select_all_studs_boxes = document.querySelectorAll('.select_all_studs');
					for (var k = 0; k < select_all_studs_boxes.length; k++) {
						select_all_studs_boxes[k].innerHTML = "Désélectionner tout";
					}
					data.all_selected = true;
				}
			}
		}

		var send_msg_sel_links = document.querySelectorAll('.send_msg_sel');
		for (var i = 0; i < send_msg_sel_links.length; i++) {
			send_msg_sel_links[i].onclick = function (e) {
				send_msg_sel(e);
			}
		}

		document.querySelector(".table-dl a").onclick = function (e) {
			e.preventDefault();
			table_download();
		}

	}

	function section_filter (section_id) {
		var cells = document.querySelectorAll('#suivi td, #suivi th');
		Array.prototype.forEach.call(cells, function (cell) {
			if (section_id == 0) {
				cell.style.display = '';
			} else {
				if ( cell.dataset.section != undefined && cell.dataset.section != section_id ) {
					cell.style.display = 'none';
				} else {
					cell.style.display = '';
				}
			}
		})
		count_lines();
	}

	function filter_students(filter) {
		var rows = document.querySelectorAll("#table-body tr");

		var all = filter == 'all';
		var inf = filter[0] == "<";
		var sup = filter[0] == ">";
		var equ = filter[0] == "=";
		var perc = filter.substring(1);
		if (all) {
			for (var i = 0; i < rows.length; i++) {
				rows[i].style.display = "";
			}
		} else {
			for (var i = 0; i < rows.length; i++) {
				var stud_perc = rows[i].dataset.percent;
				if (inf && parseInt(stud_perc) < perc) {
					rows[i].style.display = "";
				} else if (sup && parseInt(stud_perc) >= perc && perc != 0) {
					rows[i].style.display = "";
				} else if (sup && parseInt(stud_perc) > perc && perc == 0) {
					rows[i].style.display = "";
				} else if (equ && parseInt(stud_perc) == perc) {
					rows[i].style.display = "";
				} else {
					rows[i].style.display = "none";
				}
			}
		}
		count_lines();
	}

	function display_percentage() {
		var rows = document.querySelectorAll("#table-body tr");
		
		/* Calcul du nombre de modules affichés dans cette section */
		var modules = document.querySelectorAll("#modules th");
		var modules_nbr = -1;
		for (var m = 0; m < modules.length; m++) {
			if (modules[m].style.display != 'none') {
				modules_nbr++;
			}
		}

		/* Détermination du pourcentage fait et injection dans l'HTML */
		for (var i = 0; i < rows.length; i++) {
			var tds = rows[i].querySelectorAll('td');
			var done = 0;
			for (var j = 0; j < tds.length; j++) {
				var state = tds[j].getAttribute('class').replace('pointer-help state-', '');
				if ( (state == 1 || state == 2) && tds[j].style.display != "none" ) {
					done++;
				}
			}
			if (modules_nbr > 0) {
				var stud_perc = 100 * done / modules_nbr;
			} else {
				var stud_perc = 0;
			}
			rows[i].querySelector('span').innerHTML = Math.floor(stud_perc) + "% ";
			rows[i].dataset.percent = stud_perc;
		}

	}

	function select_all_studs(e) {
		e.preventDefault();
		var counter = 0;
		var checks = document.querySelectorAll("#table-body tr");
		for (var i = 0; i < checks.length; i++) {
			if ( checks[i].style.display != "none" || data.all_selected ) {
				var box = checks[i].querySelector("input[type='checkbox']");
				box.checked = !data.all_selected;
				counter++;
			}
		}
		if ( counter > 0 ) {
			var select_all_studs_boxes = document.querySelectorAll('.select_all_studs');
			for (var i = 0; i < select_all_studs_boxes.length; i++) {
				select_all_studs_boxes[i].innerHTML = data.all_selected ? "Sélectionner tout" : "Désélectionner tout"
			}
			data.all_selected = !data.all_selected;
		}
	}

	function send_msg_sel(e) {
		var user_ids = [];
		e.preventDefault();
		var rows = document.querySelectorAll("#table-body tr");
		for (var i = 0; i < rows.length; i++) {
			if ( rows[i].querySelector('input').checked ) {
				user_ids.push( rows[i].dataset.userid )
			}
		}
		document.getElementById('send_msg_input').value = user_ids
		document.getElementById('send_msg_form').submit();
	}

	function table_download() {
		var csvContent = "data:text/csv;charset=utf-8,";
		var head = ['Moodle_id', 'Prénom', 'Nom', 'Groupe', 'Complétion (en %)'];

		for ( var m = 0; m < data.modules.length; m++ ) {
			if ( data.active_section_id != data.modules[m].section && data.active_section_id != 0 ) {
				continue;
			}
			head.push('"'+data.modules[m].displayname.replace(',', '')+'"');
		}


		csvContent += head.join(",");
		csvContent += "\n";
		/* Pour chaque étudiant */
		for ( var s = 0; s < data.progress.length; s++ ) {
			var arr_cpl = [];

			/* Pour chaque activité du cours */
			var activities_nbr = 0;
			var done_activities_nbr = 0;
			for ( var mod = 0; mod < data.modules.length; mod++ ) {
				/* Si le module n'est pas dans la section actuellement filtrée */
				if ( data.active_section_id != data.modules[mod].section && data.active_section_id != 0 ) {
					continue;
				}

				var stud_progress = data.progress[s].progress
				/* Si l'étudiant n'a pas de progres*/
				if ( stud_progress.length == 0 ) {
					arr_cpl.push(0);
				} else {
					// var prog = 0;
					/* Pour chaque trace d'achèvement */
					var cpl = 0;
					for (progress in stud_progress) {
						/* Quand l'index de progression correspond à l'id du module */
						if ( data.modules[mod].id == progress ) {
							cpl = stud_progress[progress].completionstate;
							if (cpl == 3) {
								cpl = 0.5;
								cpl = '"' + cpl.toLocaleString() + '"';
							}
						}
					}
					if (cpl == 1 || cpl == 2) {
						done_activities_nbr++;
					}
					arr_cpl.push(cpl);
				}
				activities_nbr++;
			}

			// console.log(done_activities_nbr)
			// console.log(activities_nbr)
			
			var perc = Math.round(100 * 100 * done_activities_nbr / activities_nbr) / 100;

			// console.log(data.progress[s]);
			var groups = '"';
			if ( data.active_group_name != "" ) {
				groups += data.active_group_name.replace('"', '');
			} else {
				groups += data.progress[s].groups.replace('"', '');
			}
			groups += '"';
			var arr = [
			data.progress[s].id,
			data.progress[s].firstname,
			data.progress[s].lastname,
			groups,
			'"'+perc.toLocaleString()+'"',
			arr_cpl
			];
			var dataString = arr.join(",");
			csvContent += dataString + "\n";
		}
		
		// stud_cpl.forEach(function(arr, index){
		// 	var dataString = arr.join(",");
		// 	csvContent += dataString + "\n";
		// });
		
		var encodedUri = encodeURI(csvContent);

		var section_name = data.active_section_id;
		if ( section_name == 0 ) {
			section_name = "cours-complet";
		} else {
			for (var i = 0; i < data.sections.length; i++) {
				if ( data.sections[i].id == data.active_section_id ) {
					section_name = slug_it(data.sections[i].name).substring(0, 20);
				}
			}
		}
		// var section_name = slug_it(this.active_section.section_name).substring(0, 10);
		var d = new Date;
		month = d.getMonth()+1;
		date = d.getFullYear() +"."+ month.padLeft() +"."+ d.getDate().padLeft() +"-"+ d.getHours().padLeft() +"."+ d.getMinutes().padLeft() +"."+ d.getSeconds().padLeft();

		var link = document.createElement("a");
		link.setAttribute("href", encodedUri);
		link.setAttribute("download", "report-"+section_name+"-"+ date +".csv");
		document.body.appendChild(link);
		link.click();
		document.body.removeChild(link); 
	}

	function slug_it(str) {
		return str.toString().toLowerCase().trim()
		.replace(/\s+/g, '-')           /* Replace spaces with - */
		.replace(/&/g, '-and-')         /* Replace & with 'and' */
		.replace(/[^\w\-]+/g, '')       /* Remove all non-word chars */
		.replace(/\-\-+/g, '-');        /* Replace multiple - with single - */
	}

	Number.prototype.padLeft = function(base,chr){
		var  len = (String(base || 10).length - String(this).length)+1;
		return len > 0? new Array(len).join(chr || '0')+this : this;
	}

// 
})()

</script>



